@@ -24,7 +24,10 @@
 #define M365_LOCAL_CACHE_PATH "cur"
 
 /* https://docs.microsoft.com/en-us/graph/api/resources/message?view=graph-rest-1.0 */
-#define M365_FETCH_SUMMARY_PROPERTIES	"categories," \
+#define M365_FETCH_SUMMARY_PROPERTIES	"|size|" /* special prefix */ \
+					"singleValueExtendedProperties," \
+					"bodyPreview," \
+					"categories," \
 					"ccRecipients," \
 					"changeKey," \
 					"flag," \
@@ -668,6 +671,26 @@ m365_folder_update_message_info (CamelMessageInfo *mi,
 
 	changed = m365_folder_merge_server_user_flags (mi, mail) || changed;
 
+	if (!camel_message_info_get_size (mi)) {
+		gint64 i64;
+
+		i64 = e_m365_json_get_integer_single_value_extended_property (mail, E_M365_PT_MESSAGE_SIZE_NAME, 0);
+		if (i64 > 0) {
+			camel_message_info_set_size (mi, (guint32) i64);
+			changed = TRUE;
+		}
+	}
+
+	if (!camel_message_info_get_preview (mi)) {
+		const gchar *ctmp;
+
+		ctmp = e_m365_mail_message_get_body_preview (mail);
+		if (ctmp && *ctmp) {
+			camel_message_info_set_preview (mi, ctmp);
+			changed = TRUE;
+		}
+	}
+
 	return changed;
 }
 
@@ -717,6 +740,7 @@ m365_folder_new_message_info_from_mail_message (CamelFolder *folder,
 	const gchar *ctmp;
 	time_t tt;
 	gchar *tmp;
+	gint64 i64;
 
 	g_return_val_if_fail (CAMEL_IS_FOLDER (folder), NULL);
 	g_return_val_if_fail (mail != NULL, NULL);
@@ -801,31 +825,22 @@ m365_folder_new_message_info_from_mail_message (CamelFolder *folder,
 		camel_message_info_set_date_received (mi, (gint64) tt);
 
 	ctmp = e_m365_mail_message_get_internet_message_id (mail);
+	if (ctmp && *ctmp)
+		camel_message_info_set_message_id (mi, camel_folder_search_util_hash_message_id (ctmp, TRUE));
 
-	if (ctmp && *ctmp) {
-		GChecksum *checksum;
-		CamelSummaryMessageID message_id;
-		guint8 *digest;
-		gsize length;
-
-		length = g_checksum_type_get_length (G_CHECKSUM_MD5);
-		digest = g_alloca (length);
-
-		checksum = g_checksum_new (G_CHECKSUM_MD5);
-		g_checksum_update (checksum, (const guchar *) ctmp, -1);
-		g_checksum_get_digest (checksum, digest, &length);
-		g_checksum_free (checksum);
-
-		memcpy (message_id.id.hash, digest, sizeof (message_id.id.hash));
-
-		camel_message_info_set_message_id (mi, message_id.id.id);
-	}
+	i64 = e_m365_json_get_integer_single_value_extended_property (mail, E_M365_PT_MESSAGE_SIZE_NAME, 0);
+	if (i64 > 0)
+		camel_message_info_set_size (mi, (guint32) i64);
 
 	camel_message_info_set_uid (mi, e_m365_mail_message_get_id (mail));
 
 	if (headers)
 		camel_message_info_take_headers (mi, headers);
 
+	ctmp = e_m365_mail_message_get_body_preview (mail);
+	if (ctmp && *ctmp)
+		camel_message_info_set_preview (mi, ctmp);
+
 	camel_message_info_set_abort_notifications (mi, FALSE);
 
 	m365_folder_update_message_info (mi, mail);
@@ -857,6 +872,8 @@ m365_folder_got_summary_messages_cb (EM365Connection *cnc,
 	if (!summary)
 		return FALSE;
 
+	camel_folder_freeze (sdd->folder);
+
 	for (link = (GSList *) results; link; link = g_slist_next (link)) {
 		EM365MailMessage *mail = link->data;
 		const gchar *id;
@@ -902,6 +919,8 @@ m365_folder_got_summary_messages_cb (EM365Connection *cnc,
 		}
 	}
 
+	camel_folder_thaw (sdd->folder);
+
 	return TRUE;
 }
 
