@@ -53,6 +53,7 @@ typedef enum _EM365ApiVersion {
 
 typedef enum {
 	E_M365_ERROR_ID_MALFORMED,
+	E_M365_ERROR_SYNC_STATE_NOT_FOUND,
 	E_M365_ERROR_ITEM_NOT_FOUND
 } EM365Error;
 
@@ -100,6 +101,10 @@ gboolean	e_m365_connection_util_read_raw_data_cb
 						 gpointer user_data, /* CamelStream * */
 						 GCancellable *cancellable,
 						 GError **error);
+gboolean	e_m365_connection_util_reencode_parts_to_base64_sync
+						(CamelMimePart *part, /* it can be a CamelMimeMessage */
+						 GCancellable *cancellable,
+						 GError **error);
 GType		e_m365_connection_get_type	(void) G_GNUC_CONST;
 
 EM365Connection *
